OiRA

Help

1. Presentazione
2. Processo di VR
3. Identificazione + Valutazione
4. Misure di miglioramento
5. Report
6. Stato 0%

# Report

A seguito della identificazione dei pericoli, della valutazione dei rischi e, dopo aver adottato le misure obbligatorie e programmato le misure di miglioramento, si genera progressivamente il documento di valutazione dei rischi.

ATTENZIONE: PRIMA DI STAMPARE LA VERSIONE FINALE DEL REPORT, CONTROLLARE DI AVER IDENTIFICATO E VALUTATO TUTTI I RISCHI PRESENTI; E’ NECESSARIO ALLEGARE IL DOCUMENTO CON LE FIGURE DELLA PREVENZIONE E TUTTI GLI ALTRI DOCUMENTI CITATI NEL TESTO, APPOSITAMENTI COMPILATI, LADDOVE NECESSARI.

Il documento deve essere munito di “data certa” o attestata dalla sottoscrizione dello stesso, da parte del datore di lavoro nonché ai soli fini della prova della data, da parte di RSPP, RLS o RLST e del Medico Competente, ove nominato.

Salva e continua

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More